<?php

namespace Drupal\Tests\prevent_version_disclosure\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests that JS asset version numbers are not disclosed on update.php.
 *
 * @group prevent_version_disclosure
 */
class PreventVersionDisclosureUpdateTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'prevent_version_disclosure',
    'user',
  ];

  /**
   * Test that JS asset URLs on update.php do not reveal version numbers.
   */
  public function testUpdatePhpJsAssetVersionObfuscation() {
    // Create and log in as admin user.
    $admin = $this->drupalCreateUser([], NULL, TRUE);
    $this->drupalLogin($admin);

    // Visit the update.php page.
    $this->drupalGet('update.php');
    $html = $this->getSession()->getPage()->getContent();

    // Assert no JS asset URL contains a plain version number pattern.
    $this->assertFalse((bool) preg_match('/\.js\?v=\d+\.\d+(\.\d+)?/', $html), 'Version numbers found in JS asset URLs on update.php.');

    // Assert JS asset URLs have an obfuscated version parameter.
    $this->assertMatchesRegularExpression('/\.js\?v=[a-zA-Z0-9]{6,}/', $html, 'JS asset URL versions on update.php are not obfuscated.');
  }

}
